import { HttpException, HttpStatus, Injectable } from '@nestjs/common';
import { UsersService } from '../users/users.service';
import { JwtService } from '@nestjs/jwt';
import { LoginDto } from './login-dto';
import { CreateUserDto } from '../users/create-user.dto';

@Injectable()
export class AuthService {
  constructor(private usersService: UsersService, private jwtService: JwtService) {}

  async validateUser(loginDto: LoginDto): Promise<any> {
    const user = await this.usersService.findOne(loginDto.email);
    if (user) {
      return user;
    }
    return null;
  }

  async login(loginDto: LoginDto) {
    // find user in db
    const user = await this.usersService.findByLogin(loginDto);
    if (!user.emailVerified) {
      throw new HttpException('Invalid credentials', HttpStatus.UNAUTHORIZED);
    }

    // generate and sign token
    const token = this._createToken(user);

    return {
      username: user.email,
      ...token,
    };
  }

  private _createToken({ email }: CreateUserDto): any {
    return {
      access_token: this.jwtService.sign({ email }),
    };
  }
}
